<?php

namespace Drupal\foldershare_s3_cors;

use Drupal\Core\Url;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleUninstallValidatorInterface;

class UninstallValidator implements ModuleUninstallValidatorInterface
{
    /**
     * Configuration Factory.
     *
     * @var \Drupal\Core\Config\ConfigFactoryInterface
     */
    protected $configFactory;

    /**
     * Constructs a new GroupFoldershareUninstallValidator.
     *
     * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
     *   The config factory.
     *
     */
    public function __construct(ConfigFactoryInterface $configFactory)
    {
        $this->configFactory = $configFactory;
    }

    /**
     * {@inheritdoc}
     */
    public function validate($module)
    {
        $reasons = [];

        $config = $this->configFactory->get("foldershare_s3_cors.settings");

        $enable_s3_cors_uploads = $config->get('enable_s3_cors_uploads');
        $configured_s3_module = $config->get("configured_s3_module");

        if ($enable_s3_cors_uploads && ($module === $configured_s3_module)) {
            $moduleSettingsUrl = Url::fromRoute("foldershare_s3_cors.settings")->toString();
            $reasons[] = t("The <b>Foldershare S3 CORS</b> module is currently configured to this module's credentials. <a href='$moduleSettingsUrl'>Remove</a> <b>$module</b> from <b>Foldershare S3 CORS</b>'s settings (or disable S3 CORS uploads for FolderShare) before uninstalling this module.");
        }
        return $reasons;
    }
}